@@ -53,7 +53,7 @@
 #'
 #' @examples
 #' \donttest{
-#' cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
+#' cdm <- mockIncidencePrevalenceRef(sampleSize = 1000)
 #' cdm <- generateDenominatorCohortSet(
 #'   cdm = cdm, name = "denominator",
 #'   cohortDateRange = c(as.Date("2008-01-01"), as.Date("2018-01-01"))
@@ -153,7 +153,7 @@ estimatePointPrevalence <- function(cdm,
 #'
 #' @examples
 #' \donttest{
-#' cdm <- mockIncidencePrevalenceRef(sampleSize = 10000)
+#' cdm <- mockIncidencePrevalenceRef(sampleSize = 1000)
 #' cdm <- generateDenominatorCohortSet(
 #'   cdm = cdm, name = "denominator",
 #'   cohortDateRange = c(as.Date("2008-01-01"), as.Date("2018-01-01"))
@@ -252,7 +252,7 @@ estimatePrevalence <- function(cdm,
     outcomeCohortId <- CDMConnector::cohortCount(cdm[[outcomeTable]]) %>% dplyr::pull("cohort_definition_id")
   }
 
-  outcomeRef <- CDMConnector::cohortSet(cdm[[outcomeTable]]) %>%
+  outcomeRef <- CDMConnector::settings(cdm[[outcomeTable]]) %>%
     dplyr::filter(.env$outcomeCohortId %in% .data$cohort_definition_id) %>%
     dplyr::collect("cohort_definition_id", "cohort_name") %>%
     dplyr::rename("outcome_cohort_id" = "cohort_definition_id",
@@ -362,7 +362,7 @@ estimatePrevalence <- function(cdm,
 
   analysisSettings <- analysisSettings %>%
     dplyr::left_join(
-      CDMConnector::cohortSet(cdm[[denominatorTable]]) %>%
+      CDMConnector::settings(cdm[[denominatorTable]]) %>%
         dplyr::rename("cohort_id" = "cohort_definition_id") %>%
         dplyr::rename_with(
           .cols = tidyselect::everything(),
@@ -378,7 +378,7 @@ estimatePrevalence <- function(cdm,
   # the denominator cohort used
   for (i in seq_along(studySpecs)) {
     prsList[names(prsList) == "attrition"][[i]] <- dplyr::bind_rows(
-      CDMConnector::cohortAttrition(cdm[[denominatorTable]]) %>%
+      CDMConnector::attrition(cdm[[denominatorTable]]) %>%
         dplyr::rename("denominator_cohort_id" = "cohort_definition_id") %>%
         dplyr::filter(.data$denominator_cohort_id ==
           studySpecs[[i]]$denominatorCohortId) %>%
@@ -400,9 +400,9 @@ estimatePrevalence <- function(cdm,
     # from 1st analysis
 
     participants <- dplyr::tbl(
-      attr(cdm, "dbcon"),
+      attr(attr(cdm, "cdm_source"), "dbcon"),
       CDMConnector::inSchema(
-        attr(cdm, "write_schema"),
+        attr(attr(cdm, "cdm_source"), "write_schema"),
         participantTables[[1]]
       )
     )
@@ -414,21 +414,20 @@ estimatePrevalence <- function(cdm,
         participants <- participants %>%
           dplyr::full_join(
             dplyr::tbl(
-              attr(cdm, "dbcon"),
+              attr(attr(cdm, "cdm_source"), "dbcon"),
               CDMConnector::inSchema(
-                attr(cdm, "write_schema"),
+                attr(attr(cdm, "cdm_source"), "write_schema"),
                 participantTables[[i]]
               )
             ),
             by = "subject_id"
           ) %>%
-          CDMConnector::computeQuery(
+          dplyr::compute(
             name = paste0(
               tablePrefix,
               "_p_", i
             ),
             temporary = FALSE,
-            schema = attr(cdm, "write_schema"),
             overwrite = TRUE
           )
       }
@@ -437,17 +436,16 @@ estimatePrevalence <- function(cdm,
     # make sure to not overwrite any existing participant table (from
     # previous function calls)
     p <- 1 + length(stringr::str_subset(
-      CDMConnector::listTables(attr(cdm, "dbcon"),
-        schema = attr(cdm, "write_schema")
+      CDMConnector::listTables(attr(attr(cdm, "cdm_source"), "dbcon"),
+        schema = attr(attr(cdm, "cdm_source"), "write_schema")
       ),
       paste0(type, "_prev_participants")
     ))
 
     participants <- participants %>%
-      CDMConnector::computeQuery(
+      dplyr::compute(
         name = paste0(type, "_prev_participants", p),
         temporary = FALSE,
-        schema = attr(cdm, "write_schema"),
         overwrite = TRUE
       )
     CDMConnector::dropTable(
